@@ -116,7 +116,7 @@ class GitLabracadabraApplicationSettings(GitLabracadabraObject):
             },
             'default_branch_protection': {
                 'type': 'integer',
-                'description': 'Determine if developers can push to master. Can take: 0 (not protected, both '
+                'description': 'Determine if developers can push to default branch. Can take: 0 (not protected, both '
                                'developers and maintainers can push new commits, force push, or delete the branch), 1 '
                                '(partially protected, developers and maintainers can push new commits, but cannot '
                                'force push or delete the branch) or 2 (fully protected, developers cannot push new '
