@@ -104,7 +104,7 @@ class GitlabracadabraParser(object):
     @classmethod
     def _type_to_classname(cls, obj_type):
         splitted = re.split('[-_]', obj_type)
-        mapped = map(lambda s: s[0].upper() + s[1:].lower(), splitted)
+        mapped = (s[0].upper() + s[1:].lower() for s in splitted)
         return 'GitLabracadabra' + ''.join(mapped)
 
     """_type_to_module()
