@@ -195,6 +195,8 @@ class TestGroup(TestCaseWithManager):
     @skipIf(gitlab_version in ['1.6.0', '1.10.0', '1.11.0', '1.13.0'], 'python-gitlab without group labels support')
     @my_vcr.use_cassette
     def test_labels(self, cass):
+        if self.gitlab_version(lt='3.2'):
+            cass.requests[4].uri = 'http://localhost/api/v4/groups/24/labels?name=delete_this_group_label'
         obj = GitLabracadabraGroup('memory', 'test/group_labels', {
             'labels': [
                 {
