@@ -184,7 +184,7 @@ class TestParser(TestCase):
 
                 .e1:
                   branches:
-                    - master
+                    - main
                     - develop
                   members:
                     bar: maintainer
@@ -195,7 +195,7 @@ class TestParser(TestCase):
             'included.yml': """
                 .e1:
                   branches:
-                    - master
+                    - main
                     - prod
                     - staging
                   members:
@@ -211,7 +211,7 @@ class TestParser(TestCase):
         self.assertEqual(d['group1/project1'], {
             'name': 'foo',
             'members': {'foo': 'developer', 'bar': 'maintainer', 'baz': 'owner'},
-            'branches': ['master', 'develop'],
+            'branches': ['main', 'develop'],
         })
 
     def test_extend_list(self):
@@ -228,21 +228,21 @@ class TestParser(TestCase):
 
                 .e1:
                   branches:
-                    - master1
+                    - main1
                     - develop1
                   members:
                     bar: maintainer
 
                 .e2:
                   branches:
-                    - master2
+                    - main2
                     - develop2
                   members:
                     baz: developer
 
                 .e3:
                   branches:
-                    - master3
+                    - main3
                     - develop3
                   members:
                     bar: developer # override .e1 maintainer
@@ -257,7 +257,7 @@ class TestParser(TestCase):
         self.assertEqual(d['group1/project1'], {
             'name': 'foo',
             'members': {'foo': 'owner', 'bar': 'developer'},
-            'branches': ['master3', 'develop3'],
+            'branches': ['main3', 'develop3'],
         })
 
     def test_extend_list_aggregate(self):
@@ -274,21 +274,21 @@ class TestParser(TestCase):
 
                 .e1:
                   branches:
-                    - master1
+                    - main1
                     - develop1
                   members:
                     bar: maintainer
 
                 .e2:
                   branches:
-                    - master2
+                    - main2
                     - develop2
                   members:
                     baz: developer
 
                 .e3:
                   branches:
-                    - master3
+                    - main3
                     - develop3
                   members:
                     bar: developer # override .e1 maintainer
@@ -303,7 +303,7 @@ class TestParser(TestCase):
         self.assertEqual(d['group1/project1'], {
             'name': 'foo',
             'members': {'foo': 'owner', 'bar': 'developer', 'baz': 'developer'},
-            'branches': ['master2', 'develop2', 'master3', 'develop3'],
+            'branches': ['main2', 'develop2', 'main3', 'develop3'],
         })
 
     def test_objects(self):
