@@ -264,6 +264,8 @@ class TestProject(TestCaseWithManager):
     @skipIf(gitlab_version in ['1.6.0'], 'python-gitlab without protected tags support')
     @my_vcr.use_cassette
     def test_protected_tags_change(self, cass):
+        if self.gitlab_version(lt='3.0'):
+            cass.requests[2].uri = 'http://localhost/api/v4/projects/19/protected_tags/v1%2E0'
         obj = GitLabracadabraProject('memory', 'test/protected_tags', {
             'protected_tags': {'v1.0': 'maintainer'},
         })
@@ -339,6 +341,8 @@ class TestProject(TestCaseWithManager):
     @skipIf(gitlab_version in ['1.11.0', '1.13.0'], 'python-gitlab without proper project labels support')
     @my_vcr.use_cassette
     def test_labels(self, cass):
+        if self.gitlab_version(lt='3.2'):
+            cass.requests[4].uri = 'http://localhost/api/v4/projects/33/labels?name=delete_me'
         obj = GitLabracadabraProject('memory', 'test/project_labels', {
             'labels': [
                 {
